@@ -17,17 +17,17 @@
 ### Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 ### MA 02110-1301, USA
 
-gvisTable <- function(data, options=list()){
+gvisTable <- function(data, options=list(), chartid){
 
   my.type <- "Table"
   dataName <- deparse(substitute(data))
 
   my.options <- list(gvis=modifyList(list(allowHtml=TRUE),options), dataName=dataName,
-                     data=list(allowed=c("number","string","date","boolean")))
+                     data=list(allowed=c("number","string","date","datetime","boolean")))
   
   checked.data <- gvisCheckTableData(data)
   
-  output <- gvisChart(type=my.type, checked.data=checked.data, options=my.options) 
+  output <- gvisChart(type=my.type, checked.data=checked.data, options=my.options, chartid=chartid) 
   
   return(output)
 }
